@@ -119,7 +119,9 @@ class ExperimentEngine:
             os.makedirs(data_dir, exist_ok=True)
         else:
             if data is None:
-                raise ValueError("Either id or data must be provided")
+                raise ValueError(
+                    "Either id or data must be provided. Data can be a path to a folder containing trained models"
+                )
             self.experiment = create_experiment(data=data, **kwargs)
 
         # Set all kwargs as instance attributes
@@ -298,6 +300,9 @@ class ExperimentEngine:
         all_features = self.experiment.get_all_features(
             date_column=self.date_column, group_column=self.group_column
         )
+        joblib.dump(
+            all_features, f"{self.experiment.path}/preprocessing/all_features.pkl"
+        )
         return all_features
 
     def preprocess_model(self, train, val=None, test=None, for_training=True):
