@@ -31,3 +31,6 @@ DB_URI = (
     else os.getenv("DB_URI", None)
 )
 OPENAI_API_KEY = os.getenv("OPENAI_API_KEY")
+LECRAPAUD_LOGFILE = os.getenv("LECRAPAUD_LOGFILE")
+LECRAPAUD_LOCAL = os.getenv("LECRAPAUD_LOCAL", False)
+LECRAPAUD_TABLE_PREFIX = os.getenv("LECRAPAUD_TABLE_PREFIX", "lecrapaud")
