@@ -10,6 +10,7 @@ from sqlalchemy.orm.attributes import InstrumentedAttribute
 from lecrapaud.db.session import get_db
 from sqlalchemy.ext.declarative import declared_attr
 from sqlalchemy.dialects.mysql import insert as mysql_insert
+from lecrapaud.config import LECRAPAUD_TABLE_PREFIX
 
 
 def with_db(func):
@@ -46,13 +47,13 @@ class Base(DeclarativeBase):
         # If the model sets __tablename__, use it (with prefix if not present)
         if "__tablename__" in cls.__dict__:
             base_name = cls.__dict__["__tablename__"]
-            if not base_name.startswith("lecrapaud_"):
-                return f"lecrapaud_{base_name}"
+            if not base_name.startswith(f"{LECRAPAUD_TABLE_PREFIX}_"):
+                return f"{LECRAPAUD_TABLE_PREFIX}_{base_name}"
             return base_name
         # Otherwise, generate from class name
         snake = camel_to_snake(cls.__name__)
         plural = pluralize(snake)
-        return f"lecrapaud_{plural}"
+        return f"{LECRAPAUD_TABLE_PREFIX}_{plural}"
 
     @classmethod
     @with_db
