@@ -18,24 +18,15 @@ from sqlalchemy import (
 from sqlalchemy.orm import relationship
 
 from lecrapaud.db.models.base import Base
-from lecrapaud.config import LECRAPAUD_TABLE_PREFIX
+from lecrapaud.db.models.utils import create_association_table
 
 # jointures
-lecrapaud_experiment_target_association = Table(
-    f"{LECRAPAUD_TABLE_PREFIX}_experiment_target_association",
-    Base.metadata,
-    Column(
-        "experiment_id",
-        BigInteger,
-        ForeignKey(f"{LECRAPAUD_TABLE_PREFIX}_experiments.id", ondelete="CASCADE"),
-        primary_key=True,
-    ),
-    Column(
-        "target_id",
-        BigInteger,
-        ForeignKey(f"{LECRAPAUD_TABLE_PREFIX}_targets.id", ondelete="CASCADE"),
-        primary_key=True,
-    ),
+lecrapaud_experiment_target_association = create_association_table(
+    name="experiment_target_association",
+    table1="experiments",
+    column1="experiment",
+    table2="targets",
+    column2="target"
 )
 
 
@@ -100,19 +91,19 @@ class Experiment(Base):
     )
 
     def get_features(self, target_number: int):
-        feature_selections = self.feature_selections
-        target_id = [t for t in self.targets if t.name == f"TARGET_{target_number}"][
-            0
-        ].id
-        feature_selection = [
-            fs for fs in feature_selections if fs.target_id == target_id
-        ][0]
-        features = [f.name for f in feature_selection.features]
+        targets = [t for t in self.targets if t.name == f"TARGET_{target_number}"]
+        if targets:
+            target_id = targets[0].id
+            feature_selection = [
+                fs for fs in self.feature_selections if fs.target_id == target_id
+            ]
+            if feature_selection:
+                feature_selection = feature_selection[0]
+                features = [f.name for f in feature_selection.features]
+                return features
 
         # fallback to path if no features found
-        if len(features) == 0:
-            features = joblib.load(f"{self.path}/TARGET_{target_number}/features.pkl")
-
+        features = joblib.load(f"{self.path}/TARGET_{target_number}/features.pkl")
         return features
 
     def get_all_features(self, date_column: str = None, group_column: str = None):
