@@ -48,6 +48,7 @@ import pandas as pd
 import numpy as np
 from itertools import product
 import joblib
+import os
 
 from sklearn.compose import ColumnTransformer
 from sklearn.decomposition import PCA
@@ -379,12 +380,20 @@ class PreprocessFeature:
         summary = summarize_dataframe(train)
         summary.to_csv(f"{self.experiment_dir}/feature_summary.csv", index=False)
 
+        # Save all features before selection
+        joblib.dump(
+            train, f"{self.preprocessing_dir}/all_features_before_selection.pkl"
+        )
+
         return train, val, test
 
     def inference(self):
+        data = self.data
+
         # PCA
-        pcas = joblib.load(f"{self.preprocessing_dir}/pcas.pkl")
-        data, _ = self.add_pca_features(self.data, pcas=pcas)
+        if os.path.exists(f"{self.preprocessing_dir}/pcas.pkl"):
+            pcas = joblib.load(f"{self.preprocessing_dir}/pcas.pkl")
+            data, _ = self.add_pca_features(data, pcas=pcas)
 
         # Encoding
         transformer = joblib.load(f"{self.preprocessing_dir}/column_transformer.pkl")
