@@ -11,6 +11,7 @@ import joblib
 import glob
 from pathlib import Path
 import pickle
+from pydantic import BaseModel
 
 os.environ["COVERAGE_FILE"] = str(Path(".coverage").resolve())
 
@@ -569,11 +570,13 @@ class ModelEngine:
         self.target_type = self._model.target_type
 
         # Load threshold
-        self.threshold = (
-            joblib.load(f"{self.path}/thresholds.pkl")
-            if self.target_type == "classification"
-            else None
-        )
+        if (
+            os.path.exists(f"{self.path}/thresholds.pkl")
+            and self.target_type == "classification"
+        ):
+            self.threshold = joblib.load(f"{self.path}/thresholds.pkl")
+        else:
+            self.threshold = None
 
         logger.info(
             f"Loaded model {self._model.model_name} and threshold {self.threshold}"
@@ -1585,9 +1588,20 @@ def plot_confusion_matrix(y_true, y_pred):
     plt.show()
 
 
+class Threshold(BaseModel):
+    threshold: float
+    precision: float
+    recall: float
+    f1: float
+
+
+class Thresholds(BaseModel):
+    thresholds: dict[str, Threshold]
+
+
 def find_best_threshold(
     prediction: pd.DataFrame, metric: str = "recall", target_value: float | None = None
-) -> dict:
+) -> Thresholds:
     """
     General function to find best threshold optimizing recall, precision, or f1.
 
@@ -1599,7 +1613,7 @@ def find_best_threshold(
     - target_value (float | None): minimum acceptable value for the chosen metric.
 
     Returns:
-    - dict: {class_label: {'threshold', 'precision', 'recall', 'f1'}}
+    - Thresholds: {class_label: {'threshold', 'precision', 'recall', 'f1'}}
     """
     assert metric in {"recall", "precision", "f1"}, "Invalid metric"
     y_true = prediction["TARGET"]
@@ -1687,14 +1701,14 @@ def find_best_threshold(
 
 
 def apply_thresholds(
-    pred_proba: pd.DataFrame, threshold: dict | int | float, classes
+    pred_proba: pd.DataFrame, threshold: Thresholds | float, classes
 ) -> pd.DataFrame:
     """
     Apply thresholds to predicted probabilities.
 
     Parameters:
     - pred_proba (pd.DataFrame): Probabilities per class.
-    - threshold (float | dict): Global threshold (float) or per-class dict from `find_best_threshold`.
+    - threshold (Thresholds | float): Global threshold (float) or per-class dict from `find_best_threshold`.
     - classes (iterable): List or array of class labels (used for binary classification).
 
     Returns:
@@ -1817,8 +1831,6 @@ def plot_threshold(prediction, threshold, precision, recall):
 
 
 # OLD - to sort out
-
-
 def print_model_estimators(target_dir: str, model_name="linear"):
     """
     Look at a specific trained model
